---
home: true
heroImage: /meltano-logo.svg
actionText: Quick Start →
actionLink: /guide/getting-started
learnMoreText: Learn More →
learnMoreLink: /about/
features:
  - title: Simplicity
    details: Make it easy for everyone  to make informed decisions about their business.
  - title: Savings
    details: Reduce time and cost for businesses that need to invest in data analytics.
  - title: Structure
    details: Allow data scientists and analysts to build a robust, well-tested, and well-documented infrastructure that follows DevOps and data engineering best practices.
footer: Meltano is a GitLab startup | MIT Licensed | Copyright © 2018-Present
---

## What is Meltano?

Meltano is an open source convention-over-configuration product for the whole data lifecycle, all the way from loading data to analyzing it.

Meltano stands for the steps of the data lifecycle:

- Model
- Extract
- Load
- Transform
- Analyze
- Notebook
- Orchestrate

To empower you and your team in this lifecycle, Meltano manifests as two tools:
1. command line interface (CLI)
1. web app (GUI)

These two tools enable you and your team to use Meltano in a few different ways:
1. Meltano as **Project** (CLI + GUI)
    - From data extraction to analysis and visualization with orchestration for automating the process
1. Meltano as **Framework** (CLI)
    - Helps you create robust data extractors and loaders
1. Meltano as **ELT** only (CLI)
    - Runtime for extracting, loading, and transforming of data
1. Meltano as **Analyze** only (GUI)
    - Interactively query, explore, visualize, and model the data (warehouse)

It leverages open source software and software development best practices including version control, CI, CD, and review apps for [data ops](https://en.wikipedia.org/wiki/DataOps), data engineering, analytics, business intelligence and data science.